@@ -41,6 +41,9 @@ def shorten_url(url):
     """
     生成短网址
     """
-    response = requests.post(url='https://dwz.cn/admin/v2/create', data=json.dumps({'url': url}),
-                             headers={'Content-Type': 'application/json', 'Token': '861201aae84688ca9dfd7bc818384ef7'})
-    return json.loads(response.text)['ShortUrl']
+    response = requests.get(f'https://api.uomg.com/api/long2dwz?dwzapi=urlcn&url={url}')
+    resp = json.loads(response.text)
+    if resp['code'] == 1 and 'ae_url' in resp:
+        return resp['ae_url']
+    else:
+        return url
